#include <iostream>
#include <algorithm>
using namespace std;

struct Vec
{
	long long x, y;
	Vec() {}
	Vec(long long x, long long y) : x(x), y(y) {}

	Vec operator-() const { return Vec(-x, -y); }
	Vec operator+(Vec b) { return Vec(x + b.x, y + b.y); }
	Vec operator-(Vec b) { return *this + (-b); }
	long long operator*(Vec b) { return x * b.x + y * b.y; }
	long long operator^(Vec b) { return x * b.y - y * b.x; }
};

double angle(Vec a, Vec b)
{
	return atan2(a ^ b, a * b);
}


bool pinseg(Vec a, Vec b, Vec o)
{
	long long h1 = (b - a) * (o - a), h2 = (a - b) * (o - b); if (h1 > h2) swap(h1, h2);
	if (h1 < 0 && h2 > 0) return false;
	return ((((o - a) ^ (b - a)) == 0));
}

bool segcrseg(Vec a, Vec b, Vec c, Vec d)
{
	long long h1, h2;
	if (pinseg(a, b, c)) return true;
	if (pinseg(a, b, d)) return true;
	if (pinseg(c, d, a)) return true;
	if (pinseg(c, d, b)) return true;
	h1 = ((b - a) ^ c); h2 = ((b - a) ^ d); if (h1 > h2) swap(h1, h2);
	if (!(h1 < 0 && h2 > 0)) return false;
	h1 = ((d - c) ^ a); h2 = ((d - c) ^ b); if (h1 > h2) swap(h1, h2);
	if (!(h1 < 0 && h2 > 0)) return false;
	return true;
}

bool pinpol(Vec o, Vec a, Vec b, Vec c, Vec d)
{
	double ang = 0;
	if (pinseg(a, b, o)) return true;
	if (pinseg(b, c, o)) return true;
	if (pinseg(c, d, o)) return true;
	if (pinseg(d, a, o)) return true;
	ang += angle(a - o, b - o);
	ang += angle(b - o, c - o);
	ang += angle(c - o, d - o);
	ang += angle(d - o, a - o);
	return (abs(ang) > 2);
}

bool segcrpol(Vec a, Vec b, Vec c, Vec d, Vec e, Vec f)
{
	if (segcrseg(e, f, a, b)) return true;
	if (segcrseg(e, f, b, c)) return true;
	if (segcrseg(e, f, c, d)) return true;
	if (segcrseg(e, f, d, a)) return true;
	return pinpol(e, a, b, c, d) && pinpol(f, a, b, c, d);
}

int main()
{
	long long n; cin >> n;
	for (long long i = 0; i < n; ++i)
	{
		Vec a, b, c, d, x; cin >> a.x >> a.y >> b.x >> b.y >> c.x >> c.y >> d.x >> d.y >> x.x >> x.y;
		Vec a2, b2;
		long long n = min(abs((5000000) / max(abs(x.x), 1ll)), abs((5000000) / max(abs(x.y), 1ll))) + 100;
		a2 = Vec(a.x + x.x * n, a.y + x.y * n);
		b2 = Vec(b.x + x.x * n, b.y + x.y * n);
		cout << (segcrpol(a, b, b2, a2, c, d) ? "Yes\n" : "No\n");
	}

 	return 0;
}