#include <iostream>
#include <vector>
using namespace std;

#define int long long

struct point{
    int x = 0, y = 0;
    point(){}
    point(int _x, int _y){
        x = _x;
        y = _y;
    }
};

point operator+ (point a, point b){
    return point(a.x + b.x, a.y + b.y);
}

point operator- (point a, point b){
    return point(a.x - b.x, a.y - b.y);
}

int sign(int a){
    if (a > 0){
        return 1;
    }
    if (a == 0){
        return 0;
    }
    return -1;
}

int cross_product(point a, point b){
    return sign(a.x * b.y - b.x * a.y);
}

int dot_product(point a, point b){
    return sign(a.x * b.x + a.y * b.y);
}

bool in_line(point a, point b, point c){
    return cross_product(b - a, c - a) == 0;
}

bool in_between(point a, point b, point c){
    return in_line(a, b, c) && dot_product(c - a, c - b) <= 0;
}

bool in_angle(point a, point o, point b, point c){
    if (in_line(o, a, b)){
        if (in_between(a, b, o)){
            return in_line(o, a, c);
        }
        return in_line(a, o, c) && !in_between(a, c, o);
    }
    return cross_product(a - o, b - o) * cross_product(a - o, c - o) >= 0 && cross_product(a - o, c - o) * cross_product(c - o, b - o) >= 0;
}

bool is_seg_inter(point a, point b, point c, point d){
    if (in_between(a, b, c) || in_between(a, b, d) || in_between(c, d, a) || in_between(c, d, b)){
        return true;
    }
    if (!in_line(a, b, c) || !in_line(a, b, d)){
        return cross_product(b - a, c - a) * cross_product(b - a, d - a) <= 0 && cross_product(d - c, a - c) * cross_product(d - c, b - c) <= 0;
    }
    return false;
}

bool in_triangle(point a, point b, point c, point d){
    return in_angle(a, b, c, d) && in_angle(b, c, a, d) && in_angle(c, a, b, d);
}

signed main()
{
    //cout << is_seg_inter(point(3, 3), point(2, 1), point(2, 2), point(4, 2)) << endl;
    //return 0;
    int tests;
    cin >> tests;
    for (int test = 0; test < tests; test++){
        point a, b, c, d, e, f, v;
        cin >> a.x >> a.y >> b.x >> b.y >> e.x >> e.y >> f.x >> f.y;
        cin >> v.x >> v.y;
        c = a + v;
        d = b + v;
        bool is_seg = is_seg_inter(a, b, e, f) || is_seg_inter(a, c, e, f) || is_seg_inter(c, d, e, f) || is_seg_inter(b, d, e, f);
        bool is_triangle = in_triangle(a, b, c, e) || in_triangle(a, b, c, f) || in_triangle(b, d, c, e) || in_triangle(b, d, c, f);
        if (is_seg || is_triangle){
            cout << "Yes" << "\n";
        }else{
            cout << "No" << "\n";
        }
    }
    return 0;
}
