#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

const ld EPS = 1e-8;

struct point
{
    ld x = 0;
    ld y = 0;

    point() {}
    point(ld x, ld y): x(x), y(y) {}
};

struct Vector
{
    ld x, y;

    Vector(ld x, ld y): x(x), y(y) {}
    Vector(point a, point b): x(b.x - a.x), y(b.y - a.y) {}
};

struct line
{
    ld a, b, c;
};

bool equal(ld a, ld b)
{
    return abs(a - b) < EPS;
}

line vec2line(point p, Vector v)
{
    ld a = -v.y;
    ld b = v.x;
    ld c = -a * p.x - b * p.y;

    return {a, b, c};
}

bool parallel(line q1, line q2)
{
    return equal(q1.a * q2.b - q2.a * q1.b, 0);
}

point intersect(line q1, line q2)
{
    ld div = q1.a * q2.b - q2.a * q1.b;
    ld x = (q2.c * q1.b - q1.c * q2.b) / div;
    ld y = (q1.c * q2.a - q2.c * q1.a) / div;
    return {x, y};
}

bool belongs(point p, line l)
{
    return abs(l.a * p.x + l.b * p.y + l.c) < EPS;
}

ld operator*(Vector a, Vector b)
{
    return a.x * b.x + a.y * b.y;
}

bool ge(ld x)
{
    return x > -EPS;
}

bool le(ld x)
{
    return x < EPS;
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int n;
    cin >> n;

    for (int i = 0; i < n; i++)
    {
        point a1, a2, b1, b2;
        Vector v(0, 0);
        cin >> a1.x >> a1.y >> a2.x >> a2.y >> b1.x >> b1.y >> b2.x >> b2.y >> v.x >> v.y;

        line la1 = vec2line(a1, v);
        line la2 = vec2line(a2, v);
        line lb1 = vec2line(b1, v);
        line lb2 = vec2line(b2, v);

        line sega = vec2line(a1, Vector(a1, a2));
        line segb = vec2line(b1, Vector(b1, b2));

        vector<pair<point, point>> pairs;

        if (parallel(la1, segb))
        {
            if (belongs(b1, la1))
                pairs.push_back({a1, b1});
            else if (belongs(b1, la2))
                pairs.push_back({a2, b1});
        }
        else
        {
            point ia1 = intersect(la1, segb);
            point ia2 = intersect(la2, segb);

            if (ge(Vector(b1, ia1) * Vector(b1, b2)) &&
                ge(Vector(b2, ia1) * Vector(b2, b1)))
                pairs.push_back({a1, ia1});
            else if (ge(Vector(b1, ia2) * Vector(b1, b2)) &&
                     ge(Vector(b2, ia2) * Vector(b2, b1)))
                pairs.push_back({a2, ia2});
        }

        if (parallel(lb1, sega))
        {
            if (belongs(a1, lb1))
                pairs.push_back({a1, b1});
            else if (belongs(a1, lb2))
                pairs.push_back({a1, b2});
        }
        else
        {
            point ib1 = intersect(lb1, sega);
            point ib2 = intersect(lb2, sega);

            if (ge(Vector(a1, ib1) * Vector(a1, a2)) &&
                ge(Vector(a2, ib1) * Vector(a2, a1)))
                pairs.push_back({ib1, b1});
            else if (ge(Vector(a1, ib2) * Vector(a1, a2)) &&
                     ge(Vector(a2, ib2) * Vector(a2, a1)))
                pairs.push_back({ib2, b2});
        }

        bool flag = false;
        for (auto p : pairs)
        {
            if (ge(Vector(p.first, p.second) * v))
            {
                cout << "Yes" << endl;
                flag = true;
                break;
            }
        }

        if (!flag)
            cout << "No" << endl;
    }

    return 0;
}