#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

const double EPS = 1e-7;

bool Less(double a, double b)
{
	return a + EPS < b;
}

bool More(double a, double b)
{
	return a - EPS > b;
}

bool Eq(double a, double b)
{
	return a + EPS > b && a - EPS < b;
}

int sign(double a)
{
	if (More(a, 0))
		return 1;
	if (Eq(a, 0))
		return 0;
	return -1;
}

struct Point
{
	double x, y;
	Point() {}
	Point(double x, double y) : x(x), y(y) {}
	Point operator + (Point p)
	{
		return Point(x + p.x, y + p.y);
	}
	Point operator - (Point p)
	{
		return Point(x - p.x, y - p.y);
	}
};

struct Straight
{
	double a, b, c;
	Straight() {}
	Straight(double a, double b, double c) : a(a), b(b), c(c) {}
	Straight(Point p1, Point p2)
	{
		a = p1.y - p2.y;
		b = p2.x - p1.x;
		c = -(b * p1.y + a * p1.x);
	}
};

double getDistance(Point p, Straight s)
{
	return (s.a * p.x + s.b * p.y + s.c) / sqrt(s.a * s.a + s.b * s.b);
}

bool intersect(Straight s, Point st, Point fn)
{
	return sign(getDistance(st, s)) != sign(getDistance(fn, s));
}

Point getIntersection(Straight s1, Straight s2)
{
	double x = (s1.b * s2.c - s2.b * s1.c) / (s1.a * s2.b - s2.a * s1.b);
	double y = (s1.a * s2.c - s2.a * s1.c) / (s2.a * s1.b - s1.a * s2.b);
	return Point(x, y);
}

bool belong(Point st, Point fn, Straight s)
{
	return sign(getDistance(st, s)) == 0 && sign(getDistance(fn, s)) == 0;
}

void resolve()
{
	Point st1, fn1, st2, fn2;
	cin >> st1.x >> st1.y >> fn1.x >> fn1.y >> st2.x >> st2.y >> fn2.x >> fn2.y;
	Point v;
	cin >> v.x >> v.y;
	Straight s1(st1, st1 + v);
	if (belong(st2, fn2, s1))
	{
		Point p = st2 - st1;
		if (sign(p.x) == sign(v.x) && sign(p.y) == sign(v.y))
		{
			cout << "Yes\n";
			return;
		}
	}
	if (intersect(s1, st2, fn2))
	{
		Straight tmp(st2, fn2);
		Point p = getIntersection(s1, tmp);
		p = p - st1;
		if (sign(p.x) == sign(v.x) && sign(p.y) == sign(v.y))
		{
			cout << "Yes\n";
			return;
		}
	}
	Straight s2(fn1, fn1 + v);
	if (belong(st2, fn2, s2))
	{
		Point p = st2 - fn1;
		if (sign(p.x) == sign(v.x) && sign(p.y) == sign(v.y))
		{
			cout << "Yes\n";
			return;
		}
	}
	if (intersect(s2, st2, fn2))
	{
		Straight tmp(st2, fn2);
		Point p = getIntersection(s2, tmp);
		p = p - fn1;
		if (sign(p.x) == sign(v.x) && sign(p.y) == sign(v.y))
		{
			cout << "Yes\n";
			return;
		}
	}
	Straight s3(st2, st2 + v);
	if (belong(st1, fn1, s3))
	{
		Point p = st2 - st1;
		if (sign(p.x) == sign(v.x) && sign(p.y) == sign(v.y))
		{
			cout << "Yes\n";
			return;
		}
	}
	if (intersect(s3, st1, fn1))
	{
		Straight tmp(st1, fn1);
		Point p = getIntersection(s3, tmp);
		p = st2 - p;
		if (sign(p.x) == sign(v.x) && sign(p.y) == sign(v.y))
		{
			cout << "Yes\n";
			return;
		}
	}
	Straight s4(fn2, fn2 + v);
	if (belong(st1, fn1, s4))
	{
		Point p = fn2 - st1;
		if (sign(p.x) == sign(v.x) && sign(p.y) == sign(v.y))
		{
			cout << "Yes\n";
			return;
		}
	}
	if (intersect(s4, st1, fn1))
	{
		Straight tmp(st1, fn1);
		Point p = getIntersection(s4, tmp);
		p = fn2 - p;
		if (sign(p.x) == sign(v.x) && sign(p.y) == sign(v.y))
		{
			cout << "Yes\n";
			return;
		}
	}
	cout << "No\n";
}

int main()
{
	int t;
	cin >> t;
	for (int i = 1; i <= t; i++)
		resolve();
	return 0;
}