#include <iostream>
#include <algorithm>
#include <vector>
#include <set>
#include <map>
#include <cmath>

#define int long long
#define ld long double
#define pb push_back
const ld INF = 2e9, eps = 1e-6;

using namespace std;

bool isEqual(ld x, ld y) {
	return fabs(x - y) < eps;
}

struct pnt {
	ld x, y;
	pnt() {}
	pnt(ld _x, ld _y) {
		x = _x, y = _y;
	}
	pnt operator - (pnt p) {
		return pnt(x - p.x, y - p.y);
	}
	pnt operator + (pnt p) {
		return pnt(x + p.x, y + p.y);
	}
	ld operator ^(pnt p) {
		return x * p.y - p.x * y;
	}
	ld operator *(pnt p) {
		return x * p.x + p.y * y;
	}
	bool isParallel(pnt p) {
		return isEqual(pnt(x, y) ^ p, 0);
	}
	void input() {
		cin >> x >> y;
	}
};


struct line {
	ld a, b, c;
	line() {}
	line(ld _a, ld _b, ld _c) {
		a = _a, b = _b, c = _c;
	}
	line(pnt p1, pnt p2) {
		a = p1.y - p2.y;
		b = p2.x - p1.x;
		c = -(a * p1.x + b * p1.y);
	}
	pnt getPerpVec() {
		return pnt(a, b);
	}
	pnt getParalVec() {
		return pnt(-b, a);
	}
	bool isParallel(line l) {
		return getParalVec().isParallel(l.getParalVec());
	}
	pnt intersect(line l) {
		if (isParallel(l)) {
			return pnt(INF, INF);
		}
		ld q = a * l.b - b * l.a;
		return pnt((b * l.c - c * l.b) / q, (c * l.a - a * l.c) / q);
	}
};

pnt a1, a2, b1, b2, c;

bool check(pnt p1, pnt p2) {
	if ((((c ^ (b1 - a1)) >= 0) || ((c ^ (b2 - a1)) >= 0)) && (((c ^ (b1 - a2)) <= 0) || ((c ^ (b2 - a2)) <= 0)))
		return true;
	if ((((c ^ (b1 - a1)) <= 0) || ((c ^ (b2 - a1)) <= 0)) && (((c ^ (b1 - a2)) >= 0) || ((c ^ (b2 - a2)) >= 0)))
		return true;
	return false;
}

bool checkLi(pnt p1) {
	//cout << (p1 - a1).x << " " << (p1 - a1).y << " " << (c * (p1 - a1)) << " " << (c * c) << '\n';
	if ((c * c) * (c * (p1 - a1)) > 0)
		return false;
	return true;
}

void solve() {
	//pnt p1 = line(pnt(0, 0), pnt(1, 0)).intersect(line(pnt(1, 1), pnt(2, 3)));
	//cout << p1.x << " " << p1.y;

	a1.input();
	a2.input();
	b1.input();
	b2.input();
	c.input();
	line l1 = line(a1, a1 + c), l2 = line(a2, a2 + c), l3 = line(b1, b2);
	pnt p1 = l1.intersect(l3), p2 = l2.intersect(l3);
	if (p1.x == INF && p1.y == INF) {
		if (checkLi(pnt(b1))) {
			cout << "No\n";
		}
		else
			cout << "Yes\n";
		return;
	}
	if (checkLi(p1)) {
		cout << "No\n";
		return;
	}
	if (check(p1, p2))
		cout << "Yes\n";
	else
		cout << "No\n";

}

signed main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);
	int t;
	cin >> t;
	while (t--)
	{
		solve();
	}
}