#include <iostream>
#include <cstdio>
#include <algorithm>
#include <vector>
#define int long long

using namespace std;

struct pt {
	int x, y;
	pt(int a = 0, int b = 0) : x(a), y(b) {}
};

pt operator * (pt &a, int k) {
	return pt(a.x * k, a.y * k);
}

pt operator + (pt a, pt b) {
	return pt(a.x + b.x, a.y + b.y);
}

pt operator - (pt& a, pt& b) {
	return pt(a.x - b.x, a.y - b.y);
}

int operator * (pt a, pt b) {
	return a.x * b.y - b.x * a.y;
}

int operator ^ (pt a, pt b) {
	return a.x * b.x + a.y * b.y;
}

struct line {
	int A, B, C;
	line(pt a, pt b) {
		A = a.y - b.y;
		B = b.x - a.x;
		C = a * b;
	}
	int get(pt d) {
		return A * d.x + B * d.y + C;
	}
};

bool is_lie(pt a, pt b, pt c) {
	return (((b - a) * (c - a)) == 0 && ((a - c) ^ (b - c)) <= 0);
}

int sign(int v) {
	if (v < 0) return -1;
	return 1;
}

bool inter(pt a, pt b, pt c, pt d) {
	if (is_lie(a, b, c)) return 1;
	if (is_lie(a, b, d)) return 1;
	if (is_lie(c, d, a)) return 1;
	if (is_lie(c, d, b)) return 1;
	if ((b - a) * (d - c) == 0) {
		return 0;
	}
	int z1 = sign((c - a) * (b - a)) == sign((b - a) * (d - a));
	int z2 = sign((a - d) * (c - d)) == sign((c - d) * (b - d));
	return z1 & z2;
}

int shift(pt a, pt v, pt c, pt d) {
	line g(c, d);
	int t1 = sign(g.get(a));
	int l = 0, r = 1e7;
	while (r - l > 1) {
		int mid = (l + r) / 2;
		pt a1 = a;
		a1 = a1 + (v * mid);
		if (sign(g.get(a1)) == t1) {
			l = mid;
		}
		else {
			r = mid;
		}
	}
	return l;
}

void solve() {
	pt a, b, c, d, v;
	cin >> a.x >> a.y >> b.x >> b.y >> c.x >> c.y >> d.x >> d.y >> v.x >> v.y;

	if (inter(a, b, c, d)) {
		cout << "Yes";
		return;
	}

	int k1 = shift(a, v, c, d);

	pt a1 = a, b1 = b;
	a1 = a1 + v * k1;
	b1 = b1 + v * k1;

	bool res = 0;

	for (int i = 0; i < 100; ++i) {
		res |= inter(a1, b1, c, d);
		a1 = a1 + v;
		b1 = b1 + v;
	}

	a1 = a, b1 = b;
	k1 = shift(b, v, v, c);
	a1 = a1 + v * k1;
	b1 = b1 + v * k1;
	for (int i = 0; i < 100; ++i) {
		res |= inter(a1, b1, c, d);
		a1 = a1 + v;
		b1 = b1 + v;
	}

	cout << ((res) ? "Yes\n" : "No\n");

}

signed main() {
#ifdef LOCAL_DEBUG
	freopen("input.txt", "r", stdin);
#endif 
	ios::sync_with_stdio(0);
	cin.tie(0);

	int q;
	cin >> q;
	while (q--) solve();

	return 0;
}