#include <iostream>
#include <cstdio>
#include <algorithm>
#include <vector>
#define int long long

using namespace std;

const int K = 3e6;

struct pt {
	int x, y;
	pt(int a = 0, int b = 0) : x(a), y(b) {}
};

pt operator * (pt& a, int k) {
	return pt(a.x * k, a.y * k);
}

pt operator + (pt a, pt b) {
	return pt(a.x + b.x, a.y + b.y);
}

pt operator - (pt& a, pt& b) {
	return pt(a.x - b.x, a.y - b.y);
}

int operator * (pt a, pt b) {
	return a.x * b.y - b.x * a.y;
}

int operator ^ (pt a, pt b) {
	return a.x * b.x + a.y * b.y;
}

int sign(int v) {
	if (v < 0) return -1;
	return 1;
}

struct line {
	int A, B, C;
	line(pt a, pt b) {
		A = a.y - b.y;
		B = b.x - a.x;
		C = a * b;
	}
	int get(pt d) {
		return sign(A * d.x + B * d.y + C);
	}
};

bool is_lie(pt a, pt b, pt c) {
	return (((b - a) * (c - a)) == 0 && ((a - c) ^ (b - c)) <= 0);
}

bool inter(pt a, pt b, pt c, pt d) {
	if (is_lie(a, b, c)) return 1;
	if (is_lie(a, b, d)) return 1;
	if (is_lie(c, d, a)) return 1;
	if (is_lie(c, d, b)) return 1;
	if ((b - a) * (d - c) == 0) {
		return 0;
	}
	int z1 = sign((c - a) * (b - a)) == sign((b - a) * (d - a));
	int z2 = sign((a - d) * (c - d)) == sign((c - d) * (b - d));
	return z1 & z2;
}

bool lie_luch(pt a, pt b, pt c) {
	return ((b - a) * (c - a) == 0) && (((b - a) ^ (c - a)) > 0);
}

bool ugl(pt a, pt o, pt b, pt c) {
	if (lie_luch(o, a, c)) return 1;
	if (lie_luch(o, b, c)) return 1;
	int sign1 = sign((b - o) * (c - o));
	int sign2 = sign((c - o) * (a - o));
	int sign3 = sign((b - o) * (a - o));
	return sign1 == sign2 && sign2 == sign3;
}

bool shift(pt a, pt v, pt c, pt d) {
	if (c.x == d.x && c.y == d.y) {
		return lie_luch(a, a + v, c);
	}
	else {
		return ugl(c, a, d, a + v);
	}
}

pt operator- (pt a) {
	return pt(-a.x, -a.y);
}

void solve() {
	pt a, b, c, d, v;
	cin >> a.x >> a.y >> b.x >> b.y >> c.x >> c.y >> d.x >> d.y >> v.x >> v.y;

	if (inter(a, b, c, d)) {
		cout << "Yes\n";
		return;
	}

	bool res = 0;
	res |= shift(a, v, c, d);
	res |= shift(b, v, c, d);
	res |= shift(c, -v, a, b);
	res |= shift(d, -v, a, b);

	cout << ((res) ? "Yes\n" : "No\n");
}

signed main() {
#ifdef LOCAL_DEBUG
	freopen("input.txt", "r", stdin);
#endif 
	ios::sync_with_stdio(0);
	cin.tie(0);

	int q;
	cin >> q;
	while (q--) solve();

	return 0;
}