#include <bits/stdc++.h>
using namespace std;

typedef long long ll;
const double eps = 1e-9;

struct Point {
    double x, y;

public:
    Point() {}
    Point(double x_, double y_): x(x_), y(y_) {}
    Point(Point a, Point b): x(b.x - a.x), y(b.y - a.y) {}

    Point operator + (Point other) {
        return Point(x + other.x, y + other.y);
    }

    Point operator * (double k) {
        return Point(x * k, y * k);
    }

    bool operator == (Point other) {
        return abs(x - other.x) < eps && abs(y - other.y) < eps;
    }

    double len() {
        return hypot(x, y);
    }

    void norm() {
        double tmp = len();
        x /= tmp;
        y /= tmp;
    }
};

double dot_product(Point a, Point b) {
    return a.x * b.x + a.y * b.y;
}

double cross_product(Point a, Point b) {
    return a.x * b.y - a.y * b.x;
}

bool check_angle(Point a, Point b, Point c) {
    return cross_product(c, a) * cross_product(c, b) <= 0;
}

bool comp(Point a, Point b) {
    if (abs(a.x - b.x) < eps) {
        return a.y - b.y < eps;
    }
    return a.x - b.x < eps;
}

bool segment_intersect(Point a, Point b, Point c, Point d) {
    if (a == b || a == c || a == d || b == c || b == d || c == d) {
        return true;
    }

    if (abs(cross_product(Point(a, b), Point(c, d))) < eps) {
        if (dot_product(a, c) * dot_product(a, d) < 0 || dot_product(b, c) * dot_product(b, d) < 0) {
            return true;
        } else {
            return false;
        }
    }

    if (cross_product(Point(a, b), Point(a, c)) * cross_product(Point(a, b), Point(a, d)) <= 0 &&
        cross_product(Point(c, d), Point(c, b) * cross_product(Point(c, d), Point(c, a))) <= 0) {
        return true;
    }

    return false;
}

signed main() {
    //freopen("../input.txt", "r", stdin);
    //freopen("../output.txt", "w", stdout);
    // ios_base::sync_with_stdio(0);cin.tie(0);

    int n;

    cin >> n;
    for (int i = 0; i < n; ++i) {
        Point a1, a2, b1, b2;
        Point v;

        cin >> a1.x >> a1.y >> a2.x >> a2.y >> b1.x >> b1.y >> b2.x >> b2.y >> v.x >> v.y;

        v.norm();
        v = v * 6e6;

        Point na1 = a1 + v;
        Point na2 = a2 + v;

        if (abs(cross_product(Point(a1, a2), v)) < eps) {
            if (segment_intersect(a1, na1, b1, b2)) {
                cout << "Yes\n";
                continue;
            } else {
                cout << "No\n";
                continue;
            }
        }

        if ((check_angle(Point(a1, na1), Point(a1, a2), Point(a1, b1)) &&
             check_angle(Point(a2, a1), Point(a2, na2), Point(a2, b1)) &&
             check_angle(Point(na1, a1), Point(na1, na2), Point(na1, b1)) &&
             check_angle(Point(na2, a2), Point(na2, na1), Point(na2, b1))) ||
            (check_angle(Point(a1, na1), Point(a1, a2), Point(a1, b2)) &&
             check_angle(Point(a2, a1), Point(a2, na2), Point(a2, b2)) &&
             check_angle(Point(na1, a1), Point(na1, na2), Point(na1, b2)) &&
             check_angle(Point(na2, a2), Point(na2, na1), Point(na2, b2))) ||
            segment_intersect(a1, na1, b1, b2) ||
            segment_intersect(a2, na2, b1, b2)) {
            cout << "Yes\n";
            continue;
        }

        cout << "No\n";
    }
    return 0;
}