#include <iostream>
#include <vector>
#include <algorithm>
#define int long long
using namespace std;



struct Point
{
    int64_t x,y;

    Point(){};

    Point(int64_t x, int64_t y) :x(x),y(y){};
};

struct Line
{
    int64_t a,b,c;

    Line(){};

    Line(Point p1, Point p2): a(p2.y - p1.y),b(p1.x - p2.x), c(-(a* p1.x + b * p1.y)){};

    int64_t relPos(Point p)
    {
        return a*p.x + b*p.y + c;
    }
};

inline int64_t orientedSquare(Point a, Point b, Point c)
{
    return (a.x - b.x) * (a.y - c.y) - (a.x - c.x) * (a.y - b.y);
}



vector <Point> convexHull(vector <Point> pts)
{
    auto cw = [&](Point a, Point b, Point c) -> bool
    {
        return orientedSquare(a,b,c) < 0;
    };

    auto ccw = [&](Point a, Point b, Point c) -> bool
    {
        return orientedSquare(a,b,c) > 0;
    };

    if (pts.size() < 3)
    {
        return pts;

    }

    sort(pts.begin(), pts.end(), [&](const Point &a, const Point &b)
         {
             return make_pair(a.x, a.y) < make_pair(b.x, b.y);
         });
    Point pUp = pts.front(), pDown = pts.back();
    vector <Point> up, down;
    up.push_back(pUp);
    down.push_back(pUp);
    for (int i=1; i<(int)pts.size(); i++)
    {
        if (i==(int)pts.size() - 1 || cw(pUp, pts[i], pDown))
        {
            while((int)up.size() >=2 && !cw(up[(int)up.size()-2], up.back(), pts[i])) up.pop_back();
            up.push_back(pts[i]);
        }

        if (i==(int)pts.size() - 1 || ccw(pUp, pts[i], pDown))
        {
            while((int)down.size() >=2 && !ccw(down[(int)down.size()-2], down.back(), pts[i])) down.pop_back();
            down.push_back(pts[i]);
        }
    }

    for (int i = (int)down.size() - 2; i>0; i--)
    {
        up.push_back(down[i]);
    }
    return up;
}


inline bool pointInTriangle(Point a, Point b, Point c, Point p)
{
    return
    (
        Line(a,b).relPos(p) <= 0 &&
        Line(b,c).relPos(p) <= 0 &&
        Line(c,a).relPos(p) <= 0
    ) || (
          Line(a,b).relPos(p) >= 0 &&
          Line(b,c).relPos(p) >= 0 &&
          Line(c,a).relPos(p) >= 0
    );
}

inline bool intersect_l(int a, int b, int c, int d)
{
    if (a>b) swap(a,b);
    if (c>d) swap(c,d);
    return max(a,c) <=min(b,d);
}

bool intersect(Point a, Point b, Point c, Point d)
{
    return intersect_l(a.x, b.x, c.x, d.x) && intersect_l(a.y, b.y, c.y, d.y) && orientedSquare(a,b,c) * orientedSquare(a,b,d) <= 0 && orientedSquare(c,d,a) * orientedSquare(c,d,b) <=0;
}

int32_t main()
{
    cin.tie(0);
    cout.tie(0);
    ios_base::sync_with_stdio(false);
    int n;
    cin>>n;
    for (int i=0; i<n; i++)
    {
        int ax1,ay1,ax2,ay2,bx1,by1,bx2,by2,vx,vy;
        cin>>ax1>>ay1>>ax2>>ay2>>bx1>>by1>>bx2>>by2>>vx>>vy;
        ax1+=2e6;
        ax2+=2e6;
        ay1+=2e6;
        ay2+=2e6;
        bx1+=2e6;
        bx2+=2e6;
        by1+=2e6;
        by2+=2e6;
        vx+=2e6;
        vy+=2e6;
        int qx,qy,qx1,qy1,qx2,qy2;
        if (abs(vx)>abs(vy))
        {
            int k=abs((1e9/vx));
            qx=k*vx;
            qy=k*vy;
        }
        else
        {
            int k=abs((1e9/vy));
            qx=k*vx;
            qy=k*vy;
        }
        qx1=ax1+qx;
        qy1=ay1+qy;
        qx2=ax2+qx;
        qy2=ay2+qy;
        //cout<<qx1<<" "<<qy1<<" "<<qx2<<" "<<qy2<<endl;
        if (intersect({ax1,ay1},{qx1,qy1},{bx1,by1},{bx2,by2})||intersect({ax2,ay2},{qx2,qy2},{bx1,by1},{bx2,by2}))
        {
            cout<<"Yes"<<'\n';
            continue;
        }
        cout<<"No"<<'\n';
    }
    return 0;
}
